@@ -78,7 +78,7 @@ test_that("build_from_derived", {
   adsl_part <-
      select(safetyData::adam_adsl, all_of(adsl_part_vars))
 
-  adae_man <- full_join(adsl_part, ae_part, by = c("STUDYID", "USUBJID")) %>%
+  adae_man <- full_join(adsl_part, ae_part, by = c("STUDYID", "USUBJID"), multiple = "all") %>%
      rename(TRTA = TRT01A, TRTAN = TRT01AN) %>%
      select(all_of(names(adae_auto)), everything())
   expect_equal(adae_auto,adae_man )
