@@ -12,7 +12,7 @@ test_that("metatools_example", {
 })
 
 test_that("make_lone_dataset", {
-   load(metacore_example("pilot_ADaM.rda"))
+   load(metacore::metacore_example("pilot_ADaM.rda"))
    expect_error(make_lone_dataset(metacore, NULL), "Requires either a subsetted metacore object or a dataset name")
 
    ds_spec <- make_lone_dataset(metacore, "ADSL")$ds_spec
